@@ -217,21 +217,21 @@ def make_fispact_material(mat) -> str:
 def make_serpent_material(mat) -> str:
     """Returns the material in a string compatable with Serpent II"""
 
-    if mat.material_tag is None:
-        name = mat.material_name
-    else:
-        name = mat.material_tag
-
     if mat.zaid_suffix is None:
         zaid_suffix = ""
     else:
         zaid_suffix = mat.zaid_suffix
 
+    if mat.name is None:
+        name = ''
+    else:
+        name = mat.name
+
     mat_card = ["mat " + name + " " +
                 str(mat.openmc_material.get_mass_density())]
     if mat.temperature_to_neutronics_code is True:
-        if mat.temperature_in_K is not None:
-            mat_card[0] = mat_card[0] + ' tmp ' + str(mat.temperature_in_K)
+        if mat.temperature is not None:
+            mat_card[0] = mat_card[0] + ' tmp ' + str(mat.temperature)
         # should check if percent type is 'ao' or 'wo'
 
     for isotope in mat.openmc_material.nuclides:
@@ -260,16 +260,16 @@ def make_mcnp_material(mat) -> str:
             "Material.material_id needs setting before mcnp_material can be made"
         )
 
-    if mat.material_tag is None:
-        name = mat.material_name
-    else:
-        name = mat.material_tag
-
     if mat.zaid_suffix is None:
         zaid_suffix = ""
     else:
         zaid_suffix = mat.zaid_suffix
 
+    if mat.name is None:
+        name = ''
+    else:
+        name = mat.name
+
     mat_card = [
         "c     "
         + name
@@ -310,21 +310,16 @@ def make_shift_material(mat) -> str:
         raise ValueError(
             "Material.material_id needs setting before shift_material can be made"
         )
-    if mat.temperature_in_K is None:
+    if mat.temperature is None:
         raise ValueError(
-            "Material.temperature_in_K needs setting before shift_material can be made"
+            "Material.temperature needs setting before shift_material can be made"
         )
 
-    if mat.material_tag is None:
-        name = mat.material_name
-    else:
-        name = mat.material_tag
-
     mat_card = [
         "[COMP][MATERIAL]\n"
-        + "name %s\n" % name
+        + "name %s\n" % mat.name
         + "matid %s\n" % mat.material_id
-        + "tmp %s" % mat.temperature_in_K
+        + "tmp %s" % mat.temperature
     ]
     zaid = 'zaid'
     nd_ = 'nd'
@@ -359,12 +354,7 @@ def zaid_to_isotope(zaid: str) -> str:
 def AddMaterialFromDir(directory: str, verbose: bool = True):
     """Add materials to the internal library from a directory of json files"""
     for filename in Path(directory).rglob("*.json"):
-        with open(filename, "r") as f:
-            new_data = json.load(f)
-            material_dict.update(new_data)
-        if verbose:
-            print("Added materials to library from", filename)
-            print(sorted(list(new_data.keys())), "\n")
+        AddMaterialFromFile(filename, verbose)
 
 
 def AddMaterialFromFile(filename: str, verbose: Optional[bool] = True) -> None:
@@ -382,6 +372,44 @@ def AvailableMaterials() -> dict:
     return material_dict
 
 
+def SaveMaterialsToFile(filename: str, materials: list, format='json') -> str:
+    """Saves a list of materials to a json file. Useful for saving as a library
+    for future use.
+
+    Arguments:
+        filename: The output filename.
+        materials: List of neutronics_material_maker.Materials to save.
+
+    Returns
+        str: the filename of the json file
+    """
+
+    if format == 'json':
+        with open(filename, 'w') as outfile:
+            json.dump({mat.name: mat.to_json()[mat.name]
+                       for mat in materials}, outfile, indent=4)
+        return filename
+
+    all_materials = ''
+    for mat in materials:
+        if format == 'mcnp':
+            all_materials += 'c\nc\nc\n' + mat.mcnp_material
+
+        if format == 'serpent':
+            all_materials += mat.serpent_material
+
+        if format == 'shift':
+            all_materials += mat.shift_material
+
+        if format == 'fispact':
+            all_materials += mat.shift_material
+
+    with open(filename, 'w') as outfile:
+        outfile.write(all_materials)
+
+    return filename
+
+
 # loads the internal material library of materials
 material_dict = {}
 AddMaterialFromDir(Path(__file__).parent / "data", verbose=False)
